@@ -40,7 +40,7 @@ func TestChangeSupportConfig(t *testing.T) {
 					"interval": []byte("1s"),
 				}},
 			},
-			expErr: fmt.Errorf("insights secret interval must be a duration (1h, 10m) greater than or equal to one minute: too short"),
+			expErr: fmt.Errorf("insights secret interval must be a duration (1h, 10m) greater than or equal to ten seconds: too short"),
 		},
 		{name: "correct interval",
 			config: map[string]*corev1.Secret{
@@ -75,9 +75,9 @@ func TestChangeSupportConfig(t *testing.T) {
 				defaultConfig: ctrl,
 			}
 			c.mergeConfigLocked()
-			err := c.retrieveToken()
+			err := c.retrieveToken(context.Background())
 			if err == nil {
-				err = c.retrieveConfig()
+				err = c.retrieveConfig(context.Background())
 			}
 			expErrS := ""
 			if tt.expErr != nil {
